summaryrefslogtreecommitdiffstats
path: root/karbon/dockers/vdocumentdocker.cc
diff options
context:
space:
mode:
Diffstat (limited to 'karbon/dockers/vdocumentdocker.cc')
-rw-r--r--karbon/dockers/vdocumentdocker.cc60
1 files changed, 30 insertions, 30 deletions
diff --git a/karbon/dockers/vdocumentdocker.cc b/karbon/dockers/vdocumentdocker.cc
index 23e4243c..98b0b883 100644
--- a/karbon/dockers/vdocumentdocker.cc
+++ b/karbon/dockers/vdocumentdocker.cc
@@ -61,8 +61,8 @@ static long g_lastKey = 0;
* Document tab *
*************************************************************************/
-VDocumentPreview::VDocumentPreview( KarbonView* view, TQWidget* tqparent )
- : TQWidget( tqparent, "DocumentPreview" ), m_document( &view->part()->document() ), m_view( view )
+VDocumentPreview::VDocumentPreview( KarbonView* view, TQWidget* parent )
+ : TQWidget( parent, "DocumentPreview" ), m_document( &view->part()->document() ), m_view( view )
{
update();
installEventFilter( this );
@@ -220,8 +220,8 @@ VDocumentPreview::paintEvent( TQPaintEvent* )
bitBlt( this, 0, 0, &pixmap, 0, 0, width(), height() );
} // VDocumentPreview::paintEvent
-VDocumentTab::VDocumentTab( KarbonView* view, TQWidget* tqparent )
- : TQWidget( tqparent, "DocumentTab" ), m_view( view )
+VDocumentTab::VDocumentTab( KarbonView* view, TQWidget* parent )
+ : TQWidget( parent, "DocumentTab" ), m_view( view )
{
TQFrame* frame;
TQGridLayout* tqlayout = new TQGridLayout( this );
@@ -303,8 +303,8 @@ VDocumentTab::slotCommandExecuted()
* Layers tab *
*************************************************************************/
-VObjectListViewItem::VObjectListViewItem( TQListViewItem* tqparent, VObject* object, VDocument *doc, uint key, TQPtrDict<VObjectListViewItem> *map )
- : TQListViewItem( tqparent, 0L ), m_object( object ), m_document( doc ), m_key( key ), m_map( map )
+VObjectListViewItem::VObjectListViewItem( TQListViewItem* parent, VObject* object, VDocument *doc, uint key, TQPtrDict<VObjectListViewItem> *map )
+ : TQListViewItem( parent, 0L ), m_object( object ), m_document( doc ), m_key( key ), m_map( map )
{
update();
// add itself to object list item map
@@ -370,8 +370,8 @@ VObjectListViewItem::compare( TQListViewItem *i, int /*col*/, bool /*ascending*/
return m_key < objectItem->m_key ? -1 : 1;
}
-VLayerListViewItem::VLayerListViewItem( TQListView* tqparent, VLayer* layer, VDocument *doc, TQPtrDict<VLayerListViewItem> *map )
- : TQCheckListItem( tqparent, 0L, CheckBox ), m_layer( layer ), m_document( doc), m_map( map )
+VLayerListViewItem::VLayerListViewItem( TQListView* parent, VLayer* layer, VDocument *doc, TQPtrDict<VLayerListViewItem> *map )
+ : TQCheckListItem( parent, 0L, CheckBox ), m_layer( layer ), m_document( doc), m_map( map )
{
update();
// add itself to layer list item map
@@ -449,8 +449,8 @@ VLayerListViewItem::compare( TQListViewItem *i, int /*col*/, bool /*ascending*/
return m_key < layerItem->m_key ? -1 : 1;
}
-VLayersTab::VLayersTab( KarbonView* view, TQWidget* tqparent )
- : TQWidget( tqparent, "LayersTab" ), m_view( view ), m_document( &view->part()->document() )
+VLayersTab::VLayersTab( KarbonView* view, TQWidget* parent )
+ : TQWidget( parent, "LayersTab" ), m_view( view ), m_document( &view->part()->document() )
{
TQToolButton* button;
@@ -584,12 +584,12 @@ VLayersTab::selectionChangedFromTool()
VObjectListViewItem *item = m_objects[ obj ];
if( ! item )
{
- VLayerListViewItem *layerItem = m_layers[ obj->tqparent() ];
+ VLayerListViewItem *layerItem = m_layers[ obj->parent() ];
if( layerItem )
updateObjects( layerItem->layer(), layerItem );
else
{
- VObjectListViewItem *objectItem = m_objects[ obj->tqparent() ];
+ VObjectListViewItem *objectItem = m_objects[ obj->parent() ];
if( objectItem )
updateObjects( objectItem->object(), objectItem );
else
@@ -982,10 +982,10 @@ VLayersTab::updateObjects( VObject *object, TQListViewItem *item )
objectItem = new VObjectListViewItem( item, itr.current(), m_document, objcount, &m_objects );
objectItem->update();
}
- else if( objectItem->tqparent() != item )
+ else if( objectItem->parent() != item )
{
- // object found, but has false tqparent -> reparent
- objectItem->tqparent()->takeItem( objectItem );
+ // object found, but has false parent -> reparent
+ objectItem->parent()->takeItem( objectItem );
item->insertItem( objectItem );
}
@@ -1009,11 +1009,11 @@ VLayersTab::removeDeletedObjectsFromList()
// BEWARE: when deleting an item, the iterator is automatically incremented
for(; it.current(); )
{
- VLayerListViewItem *layerItem = dynamic_cast<VLayerListViewItem*>( it.current()->tqparent() );
+ VLayerListViewItem *layerItem = dynamic_cast<VLayerListViewItem*>( it.current()->parent() );
if( layerItem )
{
VGroup *group = dynamic_cast<VGroup*>( layerItem->layer() );
// check if object of item is still child of object of tqparent item
if( group && ! group->objects().contains( it.current()->object() ) )
{
layerItem->takeItem( it.current() );
@@ -1023,11 +1023,11 @@ VLayersTab::removeDeletedObjectsFromList()
}
else
{
- VObjectListViewItem *objectItem = dynamic_cast<VObjectListViewItem*>( it.current()->tqparent() );
+ VObjectListViewItem *objectItem = dynamic_cast<VObjectListViewItem*>( it.current()->parent() );
if( objectItem )
{
VGroup *group = dynamic_cast<VGroup*>( objectItem->object() );
// check if object of item is still child of object of tqparent item
if( group && ! group->objects().contains( it.current()->object() ) )
{
objectItem->takeItem( it.current() );
@@ -1085,12 +1085,12 @@ VLayersTab::slotCommandExecuted( VCommand* command )
* History tab *
*************************************************************************/
-VHistoryGroupItem::VHistoryGroupItem( VHistoryItem* item, TQListView* tqparent, TQListViewItem* after )
- : TQListViewItem( tqparent, after )
+VHistoryGroupItem::VHistoryGroupItem( VHistoryItem* item, TQListView* parent, TQListViewItem* after )
+ : TQListViewItem( parent, after )
{
setPixmap( 0, *item->pixmap( 0 ) );
setText( 0, item->text( 0 ) );
- tqparent->takeItem( item );
+ parent->takeItem( item );
insertItem( item );
m_key = item->key( 0, true );
} // VHistoryItem::VHistoryItem
@@ -1145,14 +1145,14 @@ VHistoryGroupItem::paintFocus( TQPainter*, const TQColorGroup&, const TQRect& )
} // VHistoryGroupItem::paintFocus
-VHistoryItem::VHistoryItem( VCommand* command, TQListView* tqparent, TQListViewItem* after )
- : TQListViewItem( tqparent, after ), m_command( command )
+VHistoryItem::VHistoryItem( VCommand* command, TQListView* parent, TQListViewItem* after )
+ : TQListViewItem( parent, after ), m_command( command )
{
init();
} // VHistoryItem::VHistoryItem
-VHistoryItem::VHistoryItem( VCommand* command, VHistoryGroupItem* tqparent, TQListViewItem* after )
- : TQListViewItem( tqparent, after ), m_command( command )
+VHistoryItem::VHistoryItem( VCommand* command, VHistoryGroupItem* parent, TQListViewItem* after )
+ : TQListViewItem( parent, after ), m_command( command )
{
init();
} // VHistoryItem::VHistoryItem
@@ -1200,8 +1200,8 @@ VHistoryItem::paintFocus( TQPainter*, const TQColorGroup&, const TQRect& )
} // VHistoryItem::paintFocus
-VHistoryTab::VHistoryTab( KarbonPart* part, TQWidget* tqparent )
- : TQWidget( tqparent ), m_part( part )
+VHistoryTab::VHistoryTab( KarbonPart* part, TQWidget* parent )
+ : TQWidget( parent ), m_part( part )
{
TQVBoxLayout* tqlayout = new TQVBoxLayout( this );
tqlayout->setMargin( 3 );
@@ -1298,8 +1298,8 @@ VHistoryTab::commandExecuted( VCommand* command )
if ( found )
{
m_history->repaintItem( item );
- if ( item->tqparent() )
- m_history->repaintItem( item->tqparent() );
+ if ( item->parent() )
+ m_history->repaintItem( item->parent() );
m_history->ensureItemVisible( item );
}
} // VHistoryTab::commandExecuted
@@ -1009,11 +1009,11 @@ VLayersTab::removeDeletedObjectsFromList()
{
VGroup *group = dynamic_cast<VGroup*>( layerItem->layer() );
- // check if object of item is still child of object of tqparent item
+ // check if object of item is still child of object of parent item
if( group && ! group->objects().contains( it.current()->object() ) )
{
@@ -1023,11 +1023,11 @@ VLayersTab::removeDeletedObjectsFromList()
{
VGroup *group = dynamic_cast<VGroup*>( objectItem->object() );
- // check if object of item is still child of object of tqparent item
+ // check if object of item is still child of object of parent item
if( group && ! group->objects().contains( it.current()->object() ) )
{